Independence
************

.. currentmodule:: hyppo.independence

Multiscale Graph Correlation (MGC)
----------------------------------
.. autoclass:: MGC

Distance Correlation (Dcorr)
----------------------------
.. autoclass:: Dcorr

Hilbert Schmidt Independence Criterion (Hsic)
---------------------------------------------
.. autoclass:: Hsic

Heller Heller Gorfine (HHG)
---------------------------
.. autoclass:: HHG

Cannonical Correlation Analysis (CCA)
-------------------------------------
.. autoclass:: CCA

RV
---
.. autoclass:: RV

Pearson
-------
.. autoclass:: Pearson

Kendall's tau
-------------
.. autoclass:: Kendall

Spearman's rho
--------------
.. autoclass:: Spearman
